@@ -1,9 +1,13 @@
 import os
+import re
 import string
 
 class CommandFormatter(object):
     @classmethod
-    def format(cls, comm, template_dir, files, **kwargs):
+    def format(cls, comm_type, comm, template_dir, files, **kwargs):
+        if comm_type.startswith('dependencies'): # don't process dependencies
+            return comm
+
         # If command is false/true in yaml file, it gets coverted to False/True
         # which is bool object => convert
         if isinstance(comm, bool):
@@ -20,7 +24,7 @@ class CommandFormatter(object):
         for c in parts_list:
             if isinstance(c, dict):
                 # TODO: raise a proper error if c['source'] is not present
-                new_comm.append(os.path.join(cls.template_dir, c['source']))
+                new_comm.append(os.path.join(template_dir, c['source']))
             elif c.startswith('*'):
                 c_file = c[1:].strip('{}')
                 if c_file in files:
@@ -33,5 +37,18 @@ class CommandFormatter(object):
         new_comm = ' '.join(new_comm)
 
         # substitute cli arguments for their values
-        return string.Template(new_comm).safe_substitute(kwargs)
+        substituted = string.Template(new_comm).safe_substitute(kwargs)
 
+        # we want to do homedir expansion in quotes (which bash doesn't)
+        # therefore we must hack around this here
+        regex = re.compile('\\\\*~')
+        return regex.sub(cls._homedir_expand, substituted)
+
+    @classmethod
+    def _homedir_expand(cls, matchobj):
+        if len(matchobj.group(0)) % 2 == 0:
+            # even length => odd number of backslashes => eat one and don't expand
+            return matchobj.group(0)[:-2] + '~'
+        else:
+            # odd length => even number of backslashes => expand an
+            return matchobj.group(0)[:-1] + os.path.expanduser('~')
