@@ -1,11 +1,11 @@
 import copy
-import os
 
 class Snippet(object):
-    def __init__(self, path, parsed_yaml):
-        self.path = path
-        self.name = os.path.splitext(os.path.basename(path))[0]
+    def __init__(self, name, parsed_yaml, path, template_dir=''):
+        self.name = name
         self.parsed_yaml = parsed_yaml
+        self.path = path
+        self.template_dir = template_dir
 
     @property
     def args(self):
@@ -17,6 +17,9 @@ class Snippet(object):
     def get_run_section(self, section_name='run'):
         return copy.deepcopy(self.parsed_yaml.get(section_name, None))
 
+    def get_template_dir(self):
+        return self.parsed_yaml.get('template_dir', self.template_dir)
+
     def get_dependencies_section(self, section_name='dependencies'):
         if not section_name in self.parsed_yaml:
             return None
