@@ -1,7 +1,5 @@
-from devassistant import exceptions
 from devassistant.assistants import yaml_assistant
 from devassistant.assistants.commands import run_command
-from devassistant.command_helpers import RPMHelper, YUMHelper
 
 class PathRunner(object):
     def __init__(self, path, parsed_args, override_sys_excepthook=True):
@@ -15,17 +13,6 @@ class PathRunner(object):
         if 'logging' in vars(self.path[-1].__class__) or isinstance(self.path[-1], yaml_assistant.YamlAssistant):
             self.path[-1].logging(**self.parsed_args)
 
-    def _run_path_errors(self):
-        """Gathers errors from *Assistant.errors methods
-        Returns:
-            List of found errors (empty list if everything is ok).
-        """
-        errors = []
-        for a in self.path:
-            if 'errors' in vars(a.__class__) or isinstance(a, yaml_assistant.YamlAssistant):
-                errors.extend(a.errors(**self.parsed_args))
-        return errors
-
     def _run_path_dependencies(self):
         """Runs *Assistant.dependencies methods.
         Raises:
@@ -54,9 +41,11 @@ class PathRunner(object):
             devassistant.exceptions.ExecutionException with a cause if something goes wrong
         """
         self._logging()
-        errors = self._run_path_errors()
-        if errors:
-            raise exceptions.ExecutionException(errors)
         self._run_path_dependencies()
         if not 'deps_only' in self.parsed_args:
             self._run_path_run()
+
+    def stop(self):
+        for a in self.path:
+            if 'run' in vars(a.__class__) or isinstance(a, yaml_assistant.YamlAssistant):
+                a.stop()
