@@ -6,13 +6,13 @@ from devassistant import settings
 from devassistant.assistants import snippet
 
 class YamlSnippetLoader(object):
-    snippets_dirs = list(map(lambda x: os.path.join(x, 'snippets'),settings.YAML_DIRECTORIES))
+    snippets_dirs = list(map(lambda x: os.path.join(x, 'snippets'), settings.DATA_DIRECTORIES))
     _snippets = {}
 
     @classmethod
     def _find_snippet(cls, name):
-        for path, snippet in cls._snippets.items():
-            if path.endswith(name + '.yaml'): return snippet
+        for snip in cls._snippets.values():
+            if snip.name == name: return snip
 
         return None
 
@@ -21,9 +21,13 @@ class YamlSnippetLoader(object):
         found = cls._find_snippet(name)
         if found != None:
             return found
-        struct_dict = yaml_loader.YamlLoader.load_yaml(cls.snippets_dirs, name)
-        if struct_dict != {}:
-            snip = snippet.Snippet(*struct_dict.popitem())
+        loaded = yaml_loader.YamlLoader.load_yaml(cls.snippets_dirs, name)
+        if loaded:
+            path, parsed_yaml = loaded
+            snip = snippet.Snippet(name,
+                                   parsed_yaml,
+                                   path,
+                                   template_dir=yaml_loader.YamlLoader._default_template_dir_for(path))
             cls._snippets[snip.path] = snip
             return snip
 
